==> allensdk-2.11.1-py3-none-any.whl: allensdk/brain_observatory/ecephys/copy_utility/_schemas.py <==
import hashlib

from argschema import ArgSchema
from argschema.fields import (
    LogLevel, String, Int, Nested, Boolean, List, InputFile, OutputFile)
from argschema.schemas import DefaultSchema


available_hashers = {
    'sha3_256': hashlib.sha3_256,
    'sha256': hashlib.sha256,
    None: None
}


class FileExists(InputFile):
    pass


class FileToCopy(DefaultSchema):
    source = InputFile(required=True, description='copy from here')
    destination = OutputFile(required=True,
                             description='copy to here (full path, not just '
                                         'directory!)')
    key = String(required=True,
                 description='will be passed through to outputs, allowing a '
                             'name or kind to be associated with this file')


class CopiedFile(DefaultSchema):
    source = InputFile(required=True, description='copied from here')
    destination = FileExists(required=True, description='copied to here')
    key = String(required=False, description='passed from inputs')
    source_hash = List(Int,
                       required=False)  # int array vs bytes for JSONability
    destination_hash = List(Int, required=False)


class NonFileParameters(DefaultSchema):
    use_rsync = Boolean(default=True,
                        description='copy files using rsync rather than '
                                    'shutil (this is not likely to work if '
                                    'you are running windows!)'
                        )
    hasher_key = String(default='sha256',
                        validate=lambda st: st in available_hashers,
                        allow_none=True,
                        description='select a hash function to compute over '
                                    'base64-encoded pre- and post-copy files'
                        )
    raise_if_comparison_fails = Boolean(default=True,
                                        description='if a hash comparison '
                                                    'fails, throw an error ('
                                                    'vs. a warning)')
    make_parent_dirs = Boolean(default=True,
                               description='build missing parent directories '
                                           'for destination')
    chmod = Int(default=775,
                description="destination files (and any created parents will "
                            "have these permissions")


class SessionUploadInputSchema(ArgSchema, NonFileParameters):
    log_level = LogLevel(default='INFO',
                         description='set the logging level of the module')
    files = Nested(FileToCopy, many=True, required=True,
                   description='files to be copied')


class SessionUploadOutputSchema(DefaultSchema):
    input_parameters = Nested(NonFileParameters)
    files = Nested(CopiedFile, many=True, required=True,
                   description='copied files')

==> allensdk-2.12.2-py3-none-any.whl: allensdk/brain_observatory/ecephys/copy_utility/_schemas.py <==
import hashlib
from argschema import ArgSchema
from argschema.fields import (
    LogLevel, String, Int, Nested, Boolean, List, InputFile)
from argschema.schemas import DefaultSchema


available_hashers = {
    'sha3_256': hashlib.sha3_256,
    'sha256': hashlib.sha256,
    None: None
}


class FileExists(InputFile):
    pass


class FileToCopy(DefaultSchema):
    source = InputFile(
            required=True,
            description='copy from here')
    destination = String(
            required=True,
            description='copy to here (full path, not just directory!)')
    key = String(required=True,
                 description='will be passed through to outputs, allowing a '
                             'name or kind to be associated with this file')


class CopiedFile(DefaultSchema):
    source = InputFile(required=True, description='copied from here')
    destination = FileExists(required=True, description='copied to here')
    key = String(required=False, description='passed from inputs')
    source_hash = List(Int,
                       required=False)  # int array vs bytes for JSONability
    destination_hash = List(Int, required=False)


class NonFileParameters(DefaultSchema):
    use_rsync = Boolean(default=True,
                        description='copy files using rsync rather than '
                                    'shutil (this is not likely to work if '
                                    'you are running windows!)'
                        )
    hasher_key = String(default='sha256',
                        validate=lambda st: st in available_hashers,
                        allow_none=True,
                        description='select a hash function to compute over '
                                    'base64-encoded pre- and post-copy files'
                        )
    raise_if_comparison_fails = Boolean(default=True,
                                        description='if a hash comparison '
                                                    'fails, throw an error ('
                                                    'vs. a warning)')
    make_parent_dirs = Boolean(default=True,
                               description='build missing parent directories '
                                           'for destination')
    chmod = Int(default=775,
                description="destination files (and any created parents will "
                            "have these permissions")


class SessionUploadInputSchema(ArgSchema, NonFileParameters):
    log_level = LogLevel(default='INFO',
                         description='set the logging level of the module')
    files = Nested(FileToCopy, many=True, required=True,
                   description='files to be copied')


class SessionUploadOutputSchema(DefaultSchema):
    input_parameters = Nested(NonFileParameters)
    files = Nested(CopiedFile, many=True, required=True,
                   description='copied files')
